Router

Struct Router 

pub struct Router { /* private fields */ }
A router for the Iron framework.

Drops JSON objects which are received via POST into a directory using the current date as the filename.

Implementations

Source

impl Router

pub fn new<P: Into<PathBuf>>(path: P) -> Result<Self, ConfigError>

Create a new router for a path.

pub fn handle(&self, req: &Request<Vec<u8>>) -> Result<Response<String>, Error>

Handle an incoming HTTP request.

This ends up deserializing the data as JSON if it validates. It is passed in as bytes to avoid forcing deserialization on the caller.